"use strict";(self.webpackChunknbname=self.webpackChunknbname||[]).push([[509],{509(e,t,n){n.r(t),n.d(t,{default:()=>o});const o={id:"notebook-path-injector:plugin",autoStart:!0,requires:[n(428).INotebookTracker],activate:(e,t)=>{console.log("JupyterLab extension notebook-path-injector is activated!");const n=async e=>{var t,n;const o=e.context.path,s=e.sessionContext;await s.ready;const a=`__nbname__ = "${o}"`;null===(n=null===(t=s.session)||void 0===t?void 0:t.kernel)||void 0===n||n.requestExecute({code:a,silent:!0,store_history:!1}),console.log(`Injected __nbname__ = "${o}" into kernel.`)};t.forEach(e=>{n(e)}),t.widgetAdded.connect((e,t)=>{n(t)})}}}}]);